library widget;

import 'package:euma_card/widget/euma_icon.dart';
import 'package:euma_card/widget/euma_left_tag.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

class EumaCard extends StatelessWidget {
  String _time;
  String _service;
  String _status;
  String _number;

  Widget _icon;

  double _borderRadius = 5;
  double _itemPadding = 5;
  double _leftTagWidth = 5;

  Function _onTapIcon;
  Function _onTap;

  bool _visibleTag = false;
  bool _visibleIcon = false;
  bool _visibleOval = false;

  EumaCard(this._time, this._service, this._status, this._number,
      {Widget icon,
        Function onTapIcon,
        Function onTap,
        bool visibleTag,
        bool visibleIcon,
        bool visibleOval}) {
    this._icon = icon ?? Icon(Icons.message);
    this._onTap = onTap;
    this._onTapIcon = onTapIcon;
    this._visibleTag = visibleTag ?? false;
    this._visibleIcon = visibleIcon ?? false;
    this._visibleOval = visibleOval ?? false;
  }

  @override
  Widget build(BuildContext context) {
    return _buildRootView();
  }

  Widget _buildRootView() {
    return Container(
      padding: EdgeInsets.all(10),
      child: _buildCardView(),
    );
  }

  Widget _buildCardView() {
    return Card(
      elevation: 5,
      child: MaterialButton(
        child: Stack(
          children: <Widget>[_buildContentView(), _buildLeftTag()],
        ),
        onPressed: _onTap,
        padding: EdgeInsets.all(0),
      ),
    );
  }

  Widget _buildContentView() {
    return Container(
      width: double.infinity,
      padding: EdgeInsets.only(left: 20, top: 15, bottom: 15, right: 10),
      child: Stack(
        children: <Widget>[_buildContentBody(), _buildIconView()],
      ),
      decoration: BoxDecoration(
          border:
          Border.all(color: Color.fromRGBO(161, 176, 183, 1), width: 0.5),
          borderRadius: BorderRadius.all(Radius.circular(_borderRadius))),
    );
  }

  Widget _buildContentBody() {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      mainAxisAlignment: MainAxisAlignment.center,
      children: <Widget>[
        _buildTimeView(),
        _buildServiceView(),
        _buildStatusView(),
        _buildWoNumberView()
      ],
    );
  }

  Widget _buildTimeView() {
    return Text(
      _time,
      style: TextStyle(
          fontSize: 16,
          color: Color.fromRGBO(0, 0, 0, 1),
          fontFamily: 'Poppins-Medium'),
    );
  }

  Widget _buildServiceView() {
    return Padding(
      padding: EdgeInsets.only(top: _itemPadding),
      child: Text(
        _service,
        overflow: TextOverflow.ellipsis,
        maxLines: 2,
        style: TextStyle(
            fontSize: 16,
            color: Color.fromRGBO(0, 0, 0, 1),
            fontFamily: 'Poppins-Regular'),
      ),
    );
  }

  Widget _buildStatusView() {
    return Padding(
      child: Text(
        _status,
        style: TextStyle(
            fontSize: 16,
            color: Color.fromRGBO(59, 158, 243, 1),
            fontFamily: 'Poppins-Medium'),
      ),
      padding: EdgeInsets.only(top: _itemPadding),
    );
  }

  Widget _buildWoNumberView() {
    return Padding(
      child: Opacity(
        child: Text(
          _number,
          style: TextStyle(
              fontSize: 14,
              color: Color.fromRGBO(0, 0, 0, 1),
              fontFamily: 'Poppins-Regular'),
        ),
        opacity: 0.5,
      ),
      padding: EdgeInsets.only(top: _itemPadding),
    );
  }

  Widget _buildLeftTag() {
    if (_visibleTag) {
      return Positioned(
        child: EumaLeftTag(_leftTagWidth, _borderRadius),
        top: 0,
        left: 0,
        bottom: 0,
      );
    } else {
      return Container();
    }
  }

  Widget _buildIconView() {
    if (_visibleIcon) {
      return Positioned(
        child: EumaIcon(
          _icon,
          onTap: _onTapIcon,
          visibleOval: _visibleOval,
        ),
        right: 0,
      );
    } else {
      return Container();
    }
  }
}
